%define anolis_release 1
%global _lto_cflags %{nil}

Name:           gnutls
Version:        3.8.2
Release:        %{anolis_release}%{?dist}
Summary:        A TLS protocol implementation 

License:        GPLv3+ and LGPLv2+ 
URL:            http://www.gnutls.org/ 
Source0:        https://www.gnupg.org/ftp/gcrypt/gnutls/v3.8/%{name}-%{version}.tar.xz

BuildRequires:  pkgconfig(hogweed) >= 3.6
BuildRequires:  pkgconfig(libbrotlienc) >= 1.0.0
BuildRequires:  pkgconfig(libidn2) >= 2.0.0
BuildRequires:  pkgconfig(libtasn1) >= 4.9
BuildRequires:  pkgconfig(libzstd) >= 1.3.0
BuildRequires:  pkgconfig(nettle) >= 3.6
BuildRequires:  pkgconfig(p11-kit-1) >= 0.23.1
BuildRequires:  pkgconfig(tss2-esys)
BuildRequires:  pkgconfig(tss2-mu)
BuildRequires:  pkgconfig(tss2-tctildr)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  libunistring-devel
BuildRequires:  unbound-devel
BuildRequires:  make automake autoconf gperf libtool texinfo net-tools datefudge softhsm gcc gcc-c++ gnupg2 fipscheck p11-kit-trust ca-certificates gtk-doc
Requires:       crypto-policies p11-kit-trust libtasn1 nettle 

Provides: bundled(gnulib) = 20130424

%description
GnuTLS is a secure communications library implementing the SSL, TLS and DTLS
protocols and technologies around them. It provides a simple C language
application programming interface (API) to access the secure communications
protocols as well as APIs to parse and write X.509, PKCS #12, OpenPGP and
other required structures.


%package c++
Summary: The C++ interface to GnuTLS
Requires: %{name} = %{version}-%{release}

%description c++
GnuTLS is a secure communications library implementing the SSL, TLS and DTLS
protocols and technologies around them. It provides a simple C language
application programming interface (API) to access the secure communications
protocols as well as APIs to parse and write X.509, PKCS #12, OpenPGP and
other required structures.


%package devel
Summary: Development files for the %{name} package
Requires: %{name} = %{version}-%{release}
Requires: %{name}-c++ = %{version}-%{release}
Requires: %{name}-dane = %{version}-%{release}

%description devel
GnuTLS is a secure communications library implementing the SSL, TLS and DTLS
protocols and technologies around them. It provides a simple C language
application programming interface (API) to access the secure communications
protocols as well as APIs to parse and write X.509, PKCS #12, OpenPGP and
other required structures.
This package contains files needed for developing applications with
the GnuTLS library.


%package utils
License: GPLv3+
Summary: Command line tools for TLS protocol
Requires: %{name} = %{version}-%{release}
Requires: %{name}-dane = %{version}-%{release}

%description utils
GnuTLS is a secure communications library implementing the SSL, TLS and DTLS
protocols and technologies around them. It provides a simple C language
application programming interface (API) to access the secure communications
protocols as well as APIs to parse and write X.509, PKCS #12, OpenPGP and
other required structures.
This package contains command line TLS client and server and certificate
manipulation tools.


%package dane
Summary: A DANE protocol implementation for GnuTLS
Requires: %{name} = %{version}-%{release}

%description dane
GnuTLS is a secure communications library implementing the SSL, TLS and DTLS
protocols and technologies around them. It provides a simple C language
application programming interface (API) to access the secure communications
protocols as well as APIs to parse and write X.509, PKCS #12, OpenPGP and
other required structures.
This package contains library that implements the DANE protocol for verifying
TLS certificates through DNSSEC.


%package doc
Summary: Doc files for GnuTLS
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description doc
Doc files for GnuTLS


%prep
%autosetup -p1
rm -f src/libopts/*.c src/libopts/*.h src/libopts/compat/*.c src/libopts/compat/*.h

echo "SYSTEM=NORMAL" >> tests/system.prio

%build
eval $(sed -n 's/^\(\(NAME\|VERSION_ID\)=.*\)/OS_\1/p' /etc/os-release)
export FIPS_MODULE_NAME="$OS_NAME $OS_VERSION_ID %name"

%configure \
           --without-included-libtasn1 \
           --without-included-unistring \
           --enable-fips140-mode \
           --with-fips140-module-name="$FIPS_MODULE_NAME" \
           --with-fips140-module-version=%{version}-%{srpmhash} \
           --disable-gost \
           --enable-sha1-support \
           --disable-static \
           --disable-openssl-compatibility \
           --disable-non-suiteb-curves \
           --with-system-priority-file=%{_sysconfdir}/crypto-policies/back-ends/gnutls.config \
           --with-default-trust-store-pkcs11="pkcs11:" \
           --without-tpm \
           --with-tpm2 \
           --htmldir=%{_docdir}/manual \
           --with-unbound-root-key-file=/var/lib/unbound/root.key \
           --enable-libdane \
           --disable-rpath \
           --with-default-priority-string="@SYSTEM"

%make_build V=1

%define __spec_install_post \
        %{?__debug_package:%{__debug_install_post}} \
        %{__arch_install_post} \
        %{__os_install_post} \
        rm -f $RPM_BUILD_ROOT%{_libdir}/.libgnutls.so.*.hmac \
        fipshmac -d $RPM_BUILD_ROOT%{_libdir} $RPM_BUILD_ROOT%{_libdir}/libgnutls.so.30.*.* \
        file=`basename $RPM_BUILD_ROOT%{_libdir}/libgnutls.so.30.*.hmac` && mv $RPM_BUILD_ROOT%{_libdir}/$file $RPM_BUILD_ROOT%{_libdir}/.$file && ln -s .$file $RPM_BUILD_ROOT%{_libdir}/.libgnutls.so.30.hmac \
%{nil}


%install
%make_install
make -C doc install-html DESTDIR=$RPM_BUILD_ROOT
rm -f $RPM_BUILD_ROOT%{_libdir}/guile/2.2/guile-gnutls*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/pkgconfig/gnutls-dane.pc

%generate_compatibility_deps

%find_lang gnutls

%check
%make_build check GNUTLS_SYSTEM_PRIORITY_FILE=/dev/null

%files -f gnutls.lang
%dir %{abidir}
%{_libdir}/libgnutls.so.30*
%{abidir}/libgnutls.dump
%{_libdir}/.libgnutls.so.30*.hmac
%license LICENSE doc/COPYING doc/COPYING.LESSER

%files c++
%{_libdir}/libgnutlsxx.so.*
%{abidir}/libgnutlsxx.dump

%files devel
%{_includedir}/*
%{_libdir}/libgnutls*.so
%{_libdir}/.libgnutls.so.*.hmac

%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*
%{_infodir}/gnutls*
%{_infodir}/pkcs11-vision*
%{_docdir}/manual/*

%files utils
%{_bindir}/*
%{abidir}/*-option.list
%{_mandir}/man1/*
%doc doc/certtool.cfg

%files dane
%{_libdir}/libgnutls-dane.so.*
%{abidir}/libgnutls-dane.dump

%files doc
%doc README.md AUTHORS NEWS THANKS

%changelog
* Mon Nov 20 2023 Funda Wang <fundawang@yeah.net> - 3.8.2-1
- New version 3.8.2

* Sat Feb 11 2023 Funda Wang <fundawang@yeah.net> - 3.8.0-1
- New version 3.8.0

* Thu Jan 05 2023 chen_yu_ao <m15927509890@163.com> - 3.7.8-4
- optimise spec format, generate abi files and add patch to suppress warnings

* Thu Nov 24 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 3.7.8-3
- rebuild with libunistring update

* Wed Oct 12 2022 Funda Wang <fundawang@yeah.net> - 3.7.8-2
- Clean up build requires as listed in configure.ac
- add brotli and zstd support

* Tue Oct 11 2022 Funda Wang <fundawang@yeah.ent> - 3.7.8-1
- New version 3.7.8

* Tue Aug 30 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 3.7.7-1
- update to 3.7.7

* Thu Mar 10 2022 forrest_ly <flin@linux.alibaba.com> - 3.7.3-1
- Init for Anolis OS 23
